
<!-- ページネーション -->
<div class="pagination">
    <span class="step-links">
    {% if page_obj.has_previous %}
    <a href="?page={{ page_obj.previous_page_number }}" class="text-violet">←</a>
    {% endif %}
    <span class="current">
        <strong>{{ page_obj.number }} / {{ page_obj.paginator.num_pages }}</strong>
    </span>
    {% if page_obj.has_next %}
        <a href="?page={{ page_obj.next_page_number }}" class="text-violet">→</a>
    {% endif %}
    </span>
</div>

