/* 各ページのメインバー ------------*/
.main-bar {
  padding: 20px;
}

.main-bar .jumbotron-blogs {
  background-color: white;
}

.main-bar .media-blogs {
  padding-bottom: 5%;
  border-bottom: 1px solid violet;
  margin-bottom: 5%;
}

/* 各ページのサイドバー ------------*/
.side-bar {
  padding: 30px;
  background-color: whitesmoke;
}

.side-bar .media-blogs {
  margin-bottom: 5%;
}

.side-bar .media-blogs .media {
  padding-top: 5%;
  border-top: 1px solid violet;
  margin-bottom: 5%;
}

/* ブログのトップページ------------- */
/* index.html */

.jumbotron-blogs {
  text: center;
  background-color: dimgray;
}

/* index.html blog_private.html */
.a-link {
  color: black;
}


/* index.html detail.html blog_private.html private_detail.html */
.media-body {
  padding-top: 2%;
}

/* blogs_graph.html */
.card-img-top {
        width: 100%;
}

/* new_blog.html edit_blog.html */
.blogs-title {
  margin-top: 9%;
  /*overflow: auto;*/
}

/* サイドバーのグラフ固定 blogs/category_graph.html */
.stick {
  position: -webkit-sticky;
  position: sticky;
  top: 10%;
}

