{% load mark %}
{% load static %}


<div id="toc_display" data-toggle="modal" data-target="#exampleModal">
    <img src="{% static 'icon/toc_display.png' %}" title="目次">
</div>

<!-- Modal -->
<div class="toc-modal">
  <div class="modal" id="exampleModal" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
      <div class="modal-content">
	<div class="modal-header">
	  <h5 class="modal-title" id="exampleModalLabel">目次</h5>
	  <button type="button" class="close" data-dismiss="modal" aria-label="Close">
	    <span aria-hidden="true">&times;</span>
	  </button>
	</div>
	<div class="modal-body">
	  {{ blog.get_toc | markdown_to_html }}
	</div>
	<div class="modal-footer">
	  <button type="button" class="btn btn-secondary" data-dismiss="modal">閉じる</button>
	</div>
      </div>
    </div>
  </div>
</div>
