
<!-- マークダウンの記述例をポップアップで表示 -->

<button type="button" class="btn btn-dark float-right stick" data-toggle="modal" data-target=".bd-example-modal-sm">
  Markdownx
</button>

<div class="modal fade bd-example-modal-sm" tabindex="-1" role="dialog" aria-labelledby="mySmallModalLabel" aria-hidden="true">
  <div class="modal-dialog modal-sm">
    <div class="modal-content">
      <table class="table">
	<thead>
	  <tr class="table-dark">
	    <th>内容</th>
	    <th>Markdown</th>
	  </tr>
	</thead>
	<tbody>
	  <tr>
	    <td>リンク</td>
	    <td>[リンク先名](https://){ target=_blank }</td>
	  </tr>
	  <tr>
	    <td>略語</td>
	    <td>*[単語]: 説明</td>
	  </tr>
	  <tr>
	    <td>定義リスト</td>
	    <td>単語<br>:説明</td>
	  </tr>
	  <tr>
	    <td>コードブロック</td>
	    <td>```<br># コードブロック<br>```</td>
	  </tr>
	  <tr>
	    <td>脚注</td>
	    <td>本文中に[^1]<br>[^1]:<br>本文の下の方に注記として付く</td>
	  </tr>
	  <tr>
	    <td>テーブル</td>
	    <td>Header1|Header2<br>----|----<br>Cell|Cell<br>Cell|Cell</td>
	  </tr>
	  <tr>
	    <td>忠告文</td>
	    <td>!!! overview "概要"<br>説明文<br>!!! attention "注意"<br>説明文<br>!!! supplement "補足"<br>説明文</td>
	  </tr>
	  <tr>
	    <td>正常なリスト</td>
	    <td>1. リスト１<br>2. リスト２</td>
	  </tr>
	  <tr>
	    <td>目次</td>
	    <td>[TOC]</td>
	  </tr>
	  <tr>
	    <td>インライン</td>
	    <td>`code`{ .c-h }</td>
	  </tr>
	  <tr>
	    <td>属性の追加</td>
	    <td>{ 属性=ネーム }</td>
	  </tr>
	</tbody>
      </table>
    </div>
  </div>
</div>
<!-- マークダウンの記述例をポップアップで表示END -->
